##  Diagram Views
When working with diagrams, you can select a specific view in the Views list to tailor the visualization to your needs. You can select fact sheet fields, fields on relations, fields on related fact sheets, and tags from single mode tag groups.
![Selecting a Diagram View](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b01147a4410148438f60eebda71c7_LowRes.png)
Selecting a Diagram View
In addition to standard diagram views, you can create custom fact sheet fields and tag groups that can be applied as views in diagrams.
  * Custom fact sheet fields: Custom fields do not automatically appear in diagram views. To show a custom field in diagram views, select a field in the fact sheet configuration. Navigate to the Options tab in the sidebar indicated by the gear icon. Enable the Include in views toggle, then save the changes. This option is only available for certain field types. For details, see [Showing Fields in Views](https://help.sap.com/docs/leanix/ea/fact-sheet-fields?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759fb817a44101492ded5b080b9f10c__showing_fields_in_views).
![Options Tab in the Field Configuration Sidebar on the Fact Sheet Configuration Page](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274668207a441014ac52cebc5edb7498_LowRes.png)
Options Tab in the Field Configuration Sidebar on the Fact Sheet Configuration Page
  * Tag groups: Non-empty tag groups in single mode automatically appear in diagram views. You can create additional tag groups to show them in diagram views. For more information, see [Tagging](https://help.sap.com/docs/leanix/ea/tagging?locale=en-US&state=PRODUCTION&version=CLOUD "This guide covers the essential steps for managing tags, including creating tag groups, adding and editing tags within those groups, and deleting tags and tag groups. Suggest Edits Introduction").


Related Information
[Creating Diagrams and Adding Basic Elements](https://help.sap.com/docs/leanix/ea/creating-your-first-diagram-and-adding-basic-elements?locale=en-US&state=PRODUCTION&version=CLOUD "Follow these step-by-step instructions to create your first diagram in SAP LeanIX. Learn how to use the diagram editor, add basic elements, and integrate inventory data. This guide helps you quickly understand diagramming fundamentals.")
[Managing Diagram Versions, Importing, and Exporting](https://help.sap.com/docs/leanix/ea/diagram-versions-importing-and-exporting?locale=en-US&state=PRODUCTION&version=CLOUD "Diagram versioning, import, and export features enable users to track changes, restore or compare diagram versions, and seamlessly transfer diagrams between tools such as draw.io, Lucidchart, and Visio. These capabilities support collaboration, version control, and interoperability across diagramming platforms.")
[Styles and Patterns](https://help.sap.com/docs/leanix/ea/styles-and-patterns?locale=en-US&state=PRODUCTION&version=CLOUD "Standardize the style and format of the fact sheets you create in SAP LeanIX. This ensures brand alignment and simplifies the visualization of complex data flows.")
YesNo
Send
